#ifndef BOOST_SIMD_INCLUDE_FUNCTIONS_LDEXP_HPP_INCLUDED
#define BOOST_SIMD_INCLUDE_FUNCTIONS_LDEXP_HPP_INCLUDED

#include <boost/simd/ieee/include/functions/ldexp.hpp>

#endif
